L2CapDataEvent class

L2CAP data received event.

Constructors

L2CapDataEvent({required int channelId, required List<int> data})
const
L2CapDataEvent.fromMap(Map<String, dynamic> map)
factory

Properties

channelId int
final
data List<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited