ble_plus_platform_interface library
The platform interface for ble_plus.
This package defines the abstract interfaces and shared types that all platform implementations of ble_plus must implement.
Classes
- AdvertiseSettingsData
- Settings for BLE peripheral advertising.
- BackgroundSettings
- Settings for background BLE operation.
- BleCharacteristicData
- Raw characteristic data from the platform layer.
- BleConnectionEvent
- Connection state change event from the platform.
- BleConnectionParametersData
- Connection parameters data as reported by the platform.
- BleDescriptorData
- Raw descriptor data from the platform layer.
- BlePlusPlatform
- The interface that platform-specific implementations of ble_plus must implement.
- BleScanResultData
- A scan result event from the platform layer.
- BleServiceData
- Raw service data returned from the platform layer.
- CharacteristicValueEvent
- Characteristic value update event.
- ConnectionSettings
- Settings for a BLE connection.
- GattCharacteristicDefinitionData
- Definition of a GATT characteristic for the local GATT server.
- GattDescriptorDefinitionData
- Definition of a GATT descriptor for the local GATT server.
- GattServiceDefinitionData
- Definition of a GATT service to add to the local GATT server.
- Guid
- A 128-bit UUID used for BLE services, characteristics, and descriptors.
- L2CapChannelOpenedEvent
- L2CAP channel opened on server side.
- L2CapCloseEvent
- L2CAP channel closed event.
- L2CapDataEvent
- L2CAP data received event.
- MtuChangeEvent
- MTU change event.
- PeripheralConnectionEvent
- Event when a central connects/disconnects from our peripheral GATT server.
- PlatformCapabilities
- Declares what features this platform implementation supports. Platform packages override this to reflect their actual capabilities.
- ReadRequestEvent
- Read request from a central device.
- ScanSettings
- Settings for a BLE scan operation.
- SubscriptionChangeEvent
- Subscription (notify/indicate) change event.
- WriteRequestEvent
- Write request from a central device.
Enums
- BleAdapterState
- Bluetooth adapter state.
- BleConnectionState
- Connection state enum used across platform boundary.