ScanSettings class
Settings for a BLE scan operation.
Constructors
-
ScanSettings({List<
String> ? withServices, int scanMode = 2, bool allowDuplicates = false}) -
const
Properties
- allowDuplicates → bool
-
Whether to report duplicate advertisements.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanMode → int
-
Scan mode (maps to Android ScanSettings.SCAN_MODE_*).
0 = lowPower, 1 = balanced, 2 = lowLatency, -1 = opportunistic
final
-
withServices
→ List<
String> ? -
Service UUIDs to filter by (null = no filter).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited